/*
   client/video.h
   This file is part of the Osirion project and is distributed under
   the terms and conditions of the GNU General Public License version 2
*/

#ifndef __INCLUDED_CLIENT_VIDEO_H__
#define __INCLUDED_CLIENT_VIDEO_H__

#include "core/cvar.h"

namespace client
{

/// the video subsystem
namespace video
{
/// initialize the video subsystem
bool init();

/// shutdown the video subsystem
void shutdown();

/// re-initialize the video subsystems
/** the restart functions performs a full shutdown
 *  and re-initializes the video subsystem
 */
void restart();

/// application window resize event in windowed mode
void resize(int w, int h);

/// draw the next client video frame
void frame(float elapsed);

/// draw the loader screen
void frame_loader();

/// update the loader screen message
void set_loader_message(const std::string message);

/// update the loader screen message
void set_loader_message(const char *message = 0);

/// set the window caption
void set_caption();

} // namespace video

extern core::Cvar *r_width;
extern core::Cvar *r_height;
extern core::Cvar *r_fullscreen;

extern core::Cvar *draw_ui;
extern core::Cvar *draw_stats;
extern core::Cvar *draw_devinfo;
extern core::Cvar *draw_keypress;

} // namespace client

#endif // __INCLUDED_CLIENT_VIDEO_H__
