/*
   ui/label.cc
   This file is part of the Osirion project and is distributed under
   the terms of the GNU General Public License version 2
*/

#include "math/vector2f.h"
#include "ui/paint.h"
#include "ui/label.h"

using math::Vector2f;

namespace ui
{

Label::Label(Widget *parent, const char *text) : Widget(parent)
{
	set_label("label");
	set_text(text);
	set_alignment(AlignLeft | AlignTop);
}

Label::~Label()
{
}

void Label::print(const size_t indent) const
{
	std::string marker("");
	con_print << aux::pad_left(marker, indent*2) << label() << " \"" << text() << "\"" << std::endl;
}

void Label::clear()
{
	label_text.clear();
}

void Label::set_text(const char *text)
{
	if (text)
		label_text.assign(text);
	else
		label_text.clear();
}

void Label::set_text(const std::string &text)
{
	label_text.assign(text);
}

void Label::set_alignment(const unsigned int alignment)
{
	label_alignment = alignment;
}

void Label::draw()
{
	if (!label_text.size())
		return;

	Paint::set_color(palette()->foreground());
	Paint::draw_label(global_location(), size(), font(), text(), alignment());
}

}


